pub struct Executor { /* private fields */ }Expand description
A struct representing the Executor, which manages and runs tasks in a cooperative multitasking system.
pub struct Executor { /* private fields */ }A struct representing the Executor, which manages and runs tasks in a cooperative multitasking system.